@@ -311,8 +311,8 @@ _opts = [
                 ),
     cfg.BoolOpt('enable_cinder',
                 default=False,
-                help=('Whether to install the Volume service to be boot '
-                      'overcloud nodes from remote volumes.')),
+                help=('Whether to install the Volume service. It is not '
+                      'currently used in the undercloud.')),
     cfg.BoolOpt('enable_legacy_ceilometer_api',
                 default=True,
                 help=('Whether to enable legacy ceilometer api '
@@ -678,6 +678,22 @@ def _validate_no_ip_change():
         raise validator.FailedValidation(message)
 
 
+def _validate_passwords_file():
+    """Disallow updates if the passwords file is missing
+
+    If the undercloud was already deployed, the passwords file needs to be
+    present so passwords that can't be changed are persisted.  If the file
+    is missing it will break the undercloud, so we should fail-fast and let
+    the user know about the problem.
+    """
+    if (os.path.isfile(os.path.expanduser('~/stackrc')) and
+            not os.path.isfile(PATHS.PASSWORD_PATH)):
+        message = ('The %s file is missing.  This will cause all service '
+                   'passwords to change and break the existing undercloud. ' %
+                   PATHS.PASSWORD_PATH)
+        raise validator.FailedValidation(message)
+
+
 def _validate_configuration():
     try:
         _check_hostname()
@@ -685,6 +701,7 @@ def _validate_configuration():
         _check_sysctl()
         _validate_network()
         _validate_no_ip_change()
+        _validate_passwords_file()
     except RuntimeError as e:
         LOG.error('An error occurred during configuration validation, '
                   'please check your host configuration and try again. '
@@ -1417,6 +1434,18 @@ def _handle_upgrade_fact(upgrade=False):
         _run_command(['sudo', 'chmod', '0644', fact_path])
 
 
+def _die_tuskar_die():
+    """Remove tuskar* packages
+
+    Make sure to remove tuskar https://bugs.launchpad.net/tripleo/+bug/1691744
+    # openstack-[tuskar, tuskar-ui, tuskar-ui-extras] & python-tuskarclient
+    """
+    try:
+        _run_command(['sudo', 'yum', 'remove', '-y', '*tuskar*'])
+    except subprocess.CalledProcessError as e:
+        LOG.error('Error with tuskar removal task %s - continuing', e.output)
+
+
 def install(instack_root, upgrade=False):
     """Install the undercloud
 
@@ -1432,13 +1461,22 @@ def install(instack_root, upgrade=False):
         _validate_configuration()
         instack_env = _generate_environment(instack_root)
         _generate_init_data(instack_env)
-        # We didn't complete the M->N upgrades correctly with a
-        # `nova-manage db online_data_migrations` command before. This could
-        # cause the post-upgrade db sync to fail. Better be safe than sorry and
-        # run it before package upgrade.
         if upgrade:
+            # We didn't complete the M->N upgrades correctly with a
+            # `nova-manage db online_data_migrations` command before. This
+            # could cause the post-upgrade db sync to fail. Better be safe
+            # than sorry and run it before package upgrade.
             _run_command(['sudo', '/usr/bin/nova-manage', 'db',
                           'online_data_migrations'])
+            # Even if we backport https://review.openstack.org/#/c/457478/
+            # into stable branches of puppet-ironic, we still need a way
+            # to handle existing deployments.
+            # This task will fix ironic-dbsync.log ownership on existing
+            # deployments during an upgrade. It can be removed after we
+            # release Pike.
+            _run_command(['sudo', '/usr/bin/chown', 'ironic:ironic',
+                          '/var/log/ironic/ironic-dbsync.log'])
+            _die_tuskar_die()
         if CONF.undercloud_update_packages:
             _run_yum_clean_all(instack_env)
             _run_yum_update(instack_env)
